<?php
/********************************************************************/
/* Copyright (c) 2012-2015 Ynamics SARL                             */
/* 203, rue Michel Carré, 95870 Bezons                              */
/* France                                                           */
/********************************************************************/
/* Copying and use prohibited without prior written authorisation.  */
/********************************************************************/
/* @copyright Copyright (c) 2012-2015, Ynamics SARL                 */
/* @license Proprietary, use prohibited without prior written       */
/*          authorisation                                           */
/* @link http://www.ynamics.com/                                    */
/* @author Mario De Weerd                                           */
/********************************************************************/
class JSNAppenderOptions extends CModel {
    /**
     * Only log messages with a severity equal or higher than this can be sent to the server.
     *
     * optional number TRACE
     */
    public $level;

    /**
     * If not empty, log messages only get processed if this regular expression matches the user agent string of the browser.
     * optional regular expression (empty)
     */
    public $userAgentRegex;

    /**
     * If not empty, log messages only get processed if this regular expression matches the IP address of the browser. If you use this, be sure to set the IP address via the setOptions method of the JL object.
     * optional regular expression (empty)
     */
    public $ipRegex;
    /**
     * If not empty, log messages are suppressed if they match this regular expression. If an object is being logged, it is converted to a JSON string, which is then matched.
     * optional regular expression (empty)
     */
    public $disallow;
    /**
     * If the severity of the log message is equal or greater than this, but smaller thanlevel, the log message will not be sent to the server, but stored in an internal buffer.
     * optional number ALL
     */
    public $storeInBufferLevel;

    /**
     * If the severity of a log message is equal or greater than this, not only the log message but also all log messages stored in the internal buffer will be sent to the server.
     * optional number OFF
     */
    public $sendWithBufferLevel;

    /**
     * Sets the size of the buffer used with sendWithBufferLevel andstoreInBufferLevel.
     * optional number 0
     */
    public $bufferSize;

    /**
     * Allows you to improve performance by sending multiple log messages in one go, rather than one by one.
     * optional number 1
     */
    public $batchSize;


    /**
     * All log messages will be sent to this URL. See below.
     * optional string defaultAjaxUrl
     */
    public $url;

    /**
     * Function called before an AJAX request is sent to the server. Lets you set request headers, etc. See below.
     * optional function (empty)
     *
     * ajax: code for function(xhr){} (xhr=arguments[0]).
     *      arguments[0].setRequestHeader('JSNLog-Custom-TestHeader', 'test value');
     */
    public $beforeSend;

    public function attributeNames() {
        return array('level','userAgentRegex','ipRegex','disallow','storeInBufferLevel','sendWithBufferLevel','bufferSize','batchSize','url','beforeSend');
    }

    public function getOptions() {
        $result=array();
        foreach($this->attributeNames() as $attribute) {
            if(isset($this->$attribute)) {
                // JavaScript options to embed in function.
                if(in_array($attribute,array('beforeSend'))) {
                    $result[$attribute]=new CJavaScriptExpression("function(values){{$this->$attribute}}");
                } else {
                    $result[$attribute]=$this->$attribute;
                }
            }
        }
        return $result;
    }
}
